
//==================//
// EXERCISE 140
// REVISED January 2018
//==================//

use colon, clear
drop if stage ==0
gen female = sex==2

/* Cancer mortality */
stset surv_mm, failure(status==1) scale(12) exit(time 120.5)
tab status _d
sts generate surv1_sex = s, by(female) 

/* Other cause mortality */
stset surv_mm, failure(status==2) scale(12) exit(time 120.5)
tab status _d
sts generate surv2_sex = s, by(female) 

/* Plot the complement of the Kaplan-Meier survival estimate for each cause */
gen prob1_sex = 1-surv1_sex
gen prob2_sex = 1-surv2_sex

twoway (line prob1_sex _t if female == 0, sort lcolor(black) lpattern(solid)) ///
	   (line prob2_sex _t if female == 0, sort lcolor(black) lpattern(dash)), ///
	   ytitle("Probability of Death") ///
	   xtitle("Time Since Diagnosis (Years)") ///
	   legend(order(1 "Cancer" 2 "Other Causes")) ///
	   ylabel(0(0.1)0.5, angle(0) format(%3.1f)) name(KM, replace) 

/* Estimate the cumulative incidence function (CIF) */
stset surv_mm, failure(status==1) scale(12) exit(time 120.5)
stcompet CIF_sex=ci, compet1(2) by(sex)
gen CIF_sex_cancer=CIF_sex if status==1
gen CIF_sex_other=CIF_sex if status==2

/* Plot the cumulative incidence function along with the complement of the Kaplan-Meier estimates */
twoway (line prob1_sex _t if female==0, sort lcolor(black) lpattern(solid)) ///
	   (line prob2_sex _t if female==0, sort lcolor(black) lpattern(dash)) ///
	   (line CIF_sex_cancer _t if female==0, sort lcolor(gs10) lpattern(solid)) ///
	   (line CIF_sex_other _t if female==0, sort lcolor(gs10) lpattern(dash)), ///
	   ytitle("Probability of Death") ///
	   xtitle("Time Since Diagnosis (Years)") ///
	   legend(order(1 "Cancer K-M" 2 "Other K-M" 3 "Cancer CIF" 4 "Other CIF")) ///
	   ylabel(0(0.1)0.5, angle(0) format(%3.1f)) name(KMandCIF, replace)
	

/* Estimate CIF by age group */
stset surv_mm, failure(status==1) scale(12) exit(time 120.5)
stcompet CIF_age=ci, compet1(2) by(agegrp)
	 
twoway	(line CIF_age _t if agegrp == 0 & status == 1, sort connect(stepstair)) ///	 
		(line CIF_age _t if agegrp == 1 & status == 1, sort connect(stepstair)) ///	 
		(line CIF_age _t if agegrp == 2 & status == 1, sort connect(stepstair)) ///	 
		(line CIF_age _t if agegrp == 3 & status == 1, sort connect(stepstair)) ///	 
		, legend(order(1 "<45" 2 "45-59" 3 "60-74" 4 "75+") ring(0) pos(5) cols(1)) ///
		xtitle("Years since diagnosis") ///
		ytitle("CIF") ///
		title("Cancer") ///
		name(CIF_age1,replace) 

twoway	(line CIF_age _t if agegrp == 0 & status == 2, sort connect(stepstair)) ///	 
		(line CIF_age _t if agegrp == 1 & status == 2, sort connect(stepstair)) ///	 
		(line CIF_age _t if agegrp == 2 & status == 2, sort connect(stepstair)) ///	 
		(line CIF_age _t if agegrp == 3 & status == 2, sort connect(stepstair)) ///	 
		, legend(order(1 "<45" 2 "45-59" 3 "60-74" 4 "75+") ring(0) pos(11) cols(1)) ///
		xtitle("Years since diagnosis") ///
		ytitle("CIF") ///
		title("Other causes") ///
		name(CIF_age2,replace)
		
graph combine CIF_age1 CIF_age2, nocopies ycommon		
		
/* Estimate CIF by stage */
stcompet CIF_stage=ci, compet1(2) by(stage)
	 
twoway	(line CIF_stage _t if stage == 1 & status == 1, sort connect(stepstair)) ///	 
		(line CIF_stage _t if stage == 2 & status == 1, sort connect(stepstair)) ///	 
		(line CIF_stage _t if stage == 3 & status == 1, sort connect(stepstair)) ///	 
		, legend(order(1 "local" 2 "regional" 3 "distant") ring(0) pos(5) cols(1)) ///
		xtitle("Years since diagnosis") ///
		ytitle("CIF") ///
		title("Cancer") ///
		name(CIF_stage1,replace) 

twoway	(line CIF_stage _t if stage == 1 & status == 2, sort connect(stepstair)) ///	 
		(line CIF_stage _t if stage == 2 & status == 2, sort connect(stepstair)) ///	 
		(line CIF_stage _t if stage == 3 & status == 2, sort connect(stepstair)) ///	 
		, legend(order(1 "local" 2 "regional" 3 "distant") ring(0) pos(1) cols(1)) ///
		xtitle("Years since diagnosis") ///
		ytitle("CIF") ///
		title("Other causes") ///
		name(CIF_stage2,replace) 	

graph combine CIF_stage1 CIF_stage2, nocopies ycommon		



